@@ -27,6 +27,7 @@ class TracingDispatcher extends import_dispatcher.Dispatcher {
   constructor(scope, tracing) {
     super(scope, tracing, "Tracing", {});
     this._type_Tracing = true;
+    this._started = false;
   }
   static from(scope, tracing) {
     const result = scope.connection.existingDispatcher(tracing);
@@ -34,6 +35,7 @@ class TracingDispatcher extends import_dispatcher.Dispatcher {
   }
   async tracingStart(params, progress) {
     this._object.start(params);
+    this._started = true;
   }
   async tracingStartChunk(params, progress) {
     return await this._object.startChunk(progress, params);
@@ -50,8 +52,15 @@ class TracingDispatcher extends import_dispatcher.Dispatcher {
     return { artifact: artifact ? import_artifactDispatcher.ArtifactDispatcher.from(this, artifact) : void 0, entries };
   }
   async tracingStop(params, progress) {
+    this._started = false;
     await this._object.stop(progress);
   }
+  _onDispose() {
+    if (this._started)
+      this._object.stopChunk(void 0, { mode: "discard" }).then(() => this._object.stop(void 0)).catch(() => {
+      });
+    this._started = false;
+  }
 }
 // Annotate the CommonJS export names for ESM import in node:
 0 && (module.exports = {
